==> zio-aws-ecs_2.13-5.17.160.1-sources.jar: zio/aws/ecs/model/TaskDefinitionStatus.scala <==
package zio.aws.ecs.model
import scala.jdk.CollectionConverters._
sealed trait TaskDefinitionStatus {
  def unwrap: software.amazon.awssdk.services.ecs.model.TaskDefinitionStatus
}
object TaskDefinitionStatus {
  def wrap(
      value: software.amazon.awssdk.services.ecs.model.TaskDefinitionStatus
  ): zio.aws.ecs.model.TaskDefinitionStatus = value match {
    case software.amazon.awssdk.services.ecs.model.TaskDefinitionStatus.UNKNOWN_TO_SDK_VERSION =>
      val r = unknownToSdkVersion
      r
    case software.amazon.awssdk.services.ecs.model.TaskDefinitionStatus.ACTIVE =>
      val r = ACTIVE
      r
    case software.amazon.awssdk.services.ecs.model.TaskDefinitionStatus.INACTIVE =>
      val r = INACTIVE
      r
  }
  case object unknownToSdkVersion
      extends zio.aws.ecs.model.TaskDefinitionStatus {
    override def unwrap
        : software.amazon.awssdk.services.ecs.model.TaskDefinitionStatus =
      software.amazon.awssdk.services.ecs.model.TaskDefinitionStatus.UNKNOWN_TO_SDK_VERSION
  }
  case object ACTIVE extends zio.aws.ecs.model.TaskDefinitionStatus {
    override def unwrap
        : software.amazon.awssdk.services.ecs.model.TaskDefinitionStatus =
      software.amazon.awssdk.services.ecs.model.TaskDefinitionStatus.ACTIVE
  }
  case object INACTIVE extends zio.aws.ecs.model.TaskDefinitionStatus {
    override def unwrap
        : software.amazon.awssdk.services.ecs.model.TaskDefinitionStatus =
      software.amazon.awssdk.services.ecs.model.TaskDefinitionStatus.INACTIVE
  }
}

==> zio-aws-ecs_2.13-6.20.97.2-sources.jar: zio/aws/ecs/model/TaskDefinitionStatus.scala <==
package zio.aws.ecs.model
import scala.jdk.CollectionConverters._
sealed trait TaskDefinitionStatus {
  def unwrap: software.amazon.awssdk.services.ecs.model.TaskDefinitionStatus
}
object TaskDefinitionStatus {
  def wrap(
      value: software.amazon.awssdk.services.ecs.model.TaskDefinitionStatus
  ): zio.aws.ecs.model.TaskDefinitionStatus = value match {
    case software.amazon.awssdk.services.ecs.model.TaskDefinitionStatus.UNKNOWN_TO_SDK_VERSION =>
      val r = unknownToSdkVersion
      r
    case software.amazon.awssdk.services.ecs.model.TaskDefinitionStatus.ACTIVE =>
      val r = ACTIVE
      r
    case software.amazon.awssdk.services.ecs.model.TaskDefinitionStatus.INACTIVE =>
      val r = INACTIVE
      r
    case software.amazon.awssdk.services.ecs.model.TaskDefinitionStatus.DELETE_IN_PROGRESS =>
      val r = DELETE_IN_PROGRESS
      r
  }
  case object unknownToSdkVersion
      extends zio.aws.ecs.model.TaskDefinitionStatus {
    override def unwrap
        : software.amazon.awssdk.services.ecs.model.TaskDefinitionStatus =
      software.amazon.awssdk.services.ecs.model.TaskDefinitionStatus.UNKNOWN_TO_SDK_VERSION
  }
  case object ACTIVE extends zio.aws.ecs.model.TaskDefinitionStatus {
    override def unwrap
        : software.amazon.awssdk.services.ecs.model.TaskDefinitionStatus =
      software.amazon.awssdk.services.ecs.model.TaskDefinitionStatus.ACTIVE
  }
  case object INACTIVE extends zio.aws.ecs.model.TaskDefinitionStatus {
    override def unwrap
        : software.amazon.awssdk.services.ecs.model.TaskDefinitionStatus =
      software.amazon.awssdk.services.ecs.model.TaskDefinitionStatus.INACTIVE
  }
  case object DELETE_IN_PROGRESS
      extends zio.aws.ecs.model.TaskDefinitionStatus {
    override def unwrap
        : software.amazon.awssdk.services.ecs.model.TaskDefinitionStatus =
      software.amazon.awssdk.services.ecs.model.TaskDefinitionStatus.DELETE_IN_PROGRESS
  }
}
